@@ -33,10 +33,20 @@
             parent.querySelector('.chkArhiveAsMediaContainer').classList.add('hide');
         }
 
-        if (contentType == 'homevideos') {
+        if (contentType == 'homevideos' || contentType == 'photos') {
             parent.querySelector('.chkEnablePhotosContainer').classList.remove('hide');
+            parent.querySelector('.chkDownloadImagesInAdvanceContainer').classList.add('hide');
+            parent.querySelector('.chkEnableInternetProvidersContainer').classList.add('hide');
         } else {
             parent.querySelector('.chkEnablePhotosContainer').classList.add('hide');
+            parent.querySelector('.chkDownloadImagesInAdvanceContainer').classList.remove('hide');
+            parent.querySelector('.chkEnableInternetProvidersContainer').classList.remove('hide');
+        }
+
+        if (contentType == 'photos') {
+            parent.querySelector('.chkSaveLocalContainer').classList.add('hide');
+        } else {
+            parent.querySelector('.chkSaveLocalContainer').classList.remove('hide');
         }
 
         if (contentType == 'tvshows' || contentType == 'movies' || contentType == 'homevideos' || contentType == 'musicvideos' || contentType == 'mixed' || !contentType) {
@@ -55,7 +65,10 @@
             EnablePhotos: parent.querySelector('.chkEnablePhotos').checked,
             EnableRealtimeMonitor: parent.querySelector('.chkEnableRealtimeMonitor').checked,
             ExtractChapterImagesDuringLibraryScan: parent.querySelector('.chkExtractChaptersDuringLibraryScan').checked,
-            EnableChapterImageExtraction: parent.querySelector('.chkExtractChapterImages').checked
+            EnableChapterImageExtraction: parent.querySelector('.chkExtractChapterImages').checked,
+            DownloadImagesInAdvance: parent.querySelector('#chkDownloadImagesInAdvance').checked,
+            EnableInternetProviders: parent.querySelector('#chkEnableInternetProviders').checked,
+            SaveLocalMetadata: parent.querySelector('#chkSaveLocal').checked
         };
 
         return options;
@@ -68,6 +81,9 @@
         parent.querySelector('.chkEnableRealtimeMonitor').checked = options.EnableRealtimeMonitor;
         parent.querySelector('.chkExtractChaptersDuringLibraryScan').checked = options.ExtractChapterImagesDuringLibraryScan;
         parent.querySelector('.chkExtractChapterImages').checked = options.EnableChapterImageExtraction;
+        parent.querySelector('#chkDownloadImagesInAdvance').checked = options.DownloadImagesInAdvance;
+        parent.querySelector('#chkEnableInternetProviders').checked = options.EnableInternetProviders;
+        parent.querySelector('#chkSaveLocal').checked = options.SaveLocalMetadata;
     }
 
     return {
