@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['jQuery', 'cardBuilder', 'emby-itemscontainer'], function ($, cardBuilder) {
 
     var data = {};
 
@@ -11,7 +11,7 @@
                 query: {
                     SortBy: "",
                     SortOrder: "Ascending",
-                    Fields: "PrimaryImageAspectRatio,SyncInfo",
+                    Fields: "PrimaryImageAspectRatio",
                     StartIndex: 0,
                     Limit: LibraryBrowser.getDefaultPageSize()
                 }
@@ -125,11 +125,9 @@
                 filterButton: true
             });
 
-            page.querySelector('.listTopPaging').innerHTML = pagingHtml;
-
             updateFilterControls(page);
 
-            html = LibraryBrowser.getPosterViewHtml({
+            html = cardBuilder.getCardsHtml({
                 items: result.Items,
                 shape: "auto",
                 defaultShape: 'square',
@@ -141,8 +139,14 @@
                 centerText: true
             });
 
+            var i, length;
+            var elems = page.querySelectorAll('.paging');
+            for (i = 0, length = elems.length; i < length; i++) {
+                elems[i].innerHTML = pagingHtml;
+            }
+
             var elem = page.querySelector('#items');
-            elem.innerHTML = html + pagingHtml;
+            elem.innerHTML = html;
             ImageLoader.lazyChildren(elem);
 
             $('.btnNextPage', page).on('click', function () {
@@ -247,32 +251,8 @@
 
     function updateFilterControls(page) {
 
-        var query = getQuery(page);
-        $('.alphabetPicker', page).alphaValue(query.NameStartsWith);
     }
 
-    pageIdOn('pageinit', "channelItemsPage", function () {
-
-        var page = this;
-
-        $('.alphabetPicker', this).on('alphaselect', function (e, character) {
-
-            var query = getQuery(page);
-            query.NameStartsWithOrGreater = character;
-            query.StartIndex = 0;
-
-            reloadItems(page);
-
-        }).on('alphaclear', function (e) {
-
-            var query = getQuery(page);
-            query.NameStartsWithOrGreater = '';
-
-            reloadItems(page);
-        });
-
-    });
-
     pageIdOn('pagebeforeshow', "channelItemsPage", function () {
 
         var page = this;
