@@ -15,7 +15,8 @@
                     query: {
                         StartIndex: 0,
                         EnableFavoriteSorting: true,
-                        Limit: LibraryBrowser.getDefaultPageSize()
+                        Limit: LibraryBrowser.getDefaultPageSize(),
+                        Fields: "PrimaryImageAspectRatio"
                     }
                 };
 
@@ -45,7 +46,8 @@
                 showTitle: true,
                 lazy: true,
                 cardLayout: true,
-                showDetailsMenu: true
+                showDetailsMenu: true,
+                showCurrentProgram: true
             });
         }
 
