@@ -596,13 +596,16 @@
 
         if (nowPlayingItem.Id) {
             ApiClient.getItem(Dashboard.getCurrentUserId(), nowPlayingItem.Id).then(function (item) {
-                nowPlayingUserData.innerHTML = userdataButtons.getIconsHtml({
+                userdataButtons.fill({
                     item: item,
-                    includePlayed: false
+                    includePlayed: false,
+                    element: nowPlayingUserData
                 });
             });
         } else {
-            nowPlayingUserData.innerHTML = '';
+            userdataButtons.destroy({
+                element: nowPlayingUserData
+            });
         }
     }
 
