@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['jQuery', 'libraryBrowser', 'fnchecked'], function ($, libraryBrowser) {
 
     var defaultSortBy = "SortName";
     var topItems = 5;
@@ -131,7 +131,7 @@
                 break;
             case "LockDataImage":
                 if (rRow.HasLockData) {
-                    html += '<img src="css/images/editor/lock.png"  style="width:18px"/>';
+                    html += '<i class="md-icon">lock</i>';
                 }
                 break;
             case "TagsPrimaryImage":
@@ -169,11 +169,11 @@
                 break;
             case "StatusImage":
                 if (rRow.HasLockData) {
-                    html += '<iron-icon icon="lock" style="height:18px"></iron-icon>';
+                    html += '<i class="md-icon">lock</i>';
                 }
 
                 if (!rRow.HasLocalTrailer && rRow.RowType === "Movie") {
-                    html += '<iron-icon icon="videocam" title="Missing local trailer." style="height:18px"></iron-icon>';
+                    html += '<i title="Missing local trailer." class="md-icon">videocam</i>';
                 }
 
                 if (!rRow.HasImageTagsPrimary) {
@@ -311,7 +311,7 @@
             $('#tabFilter', page).hide();
         }
 
-        var pagingHtml = LibraryBrowser.getQueryPagingHtml({
+        var pagingHtml = libraryBrowser.getQueryPagingHtml({
             startIndex: query.StartIndex,
             limit: query.Limit,
             totalRecordCount: result.TotalRecordCount,
@@ -456,7 +456,7 @@
 
             this.checked = filters.indexOf(',' + filterName) != -1;
 
-        }).checkboxradio('refresh');
+        });
 
 
         $('.chkVideoTypeFilter', page).each(function () {
@@ -466,7 +466,7 @@
 
             this.checked = filters.indexOf(',' + filterName) != -1;
 
-        }).checkboxradio('refresh');
+        });
 
         $('.chkStatus', page).each(function () {
 
@@ -475,7 +475,7 @@
 
             this.checked = filters.indexOf(',' + filterName) != -1;
 
-        }).checkboxradio('refresh');
+        });
 
         $('.chkAirDays', page).each(function () {
 
@@ -484,34 +484,33 @@
 
             this.checked = filters.indexOf(',' + filterName) != -1;
 
-        }).checkboxradio('refresh');
+        });
 
-        $('#chk3D', page).checked(query.Is3D == true).checkboxradio('refresh');
-        $('#chkHD', page).checked(query.IsHD == true).checkboxradio('refresh');
-        $('#chkSD', page).checked(query.IsHD == false).checkboxradio('refresh');
+        $('#chk3D', page).checked(query.Is3D == true);
+        $('#chkHD', page).checked(query.IsHD == true);
+        $('#chkSD', page).checked(query.IsHD == false);
 
-        $('#chkSubtitle', page).checked(query.HasSubtitles == true).checkboxradio('refresh');
-        $('#chkTrailer', page).checked(query.HasTrailer == true).checkboxradio('refresh');
-        $('#chkMissingTrailer', page).checked(query.HasTrailer == false).checkboxradio('refresh');
-        $('#chkSpecialFeature', page).checked(query.HasSpecialFeature == true).checkboxradio('refresh');
-        $('#chkThemeSong', page).checked(query.HasThemeSong == true).checkboxradio('refresh');
-        $('#chkThemeVideo', page).checked(query.HasThemeVideo == true).checkboxradio('refresh');
+        $('#chkSubtitle', page).checked(query.HasSubtitles == true);
+        $('#chkTrailer', page).checked(query.HasTrailer == true);
+        $('#chkMissingTrailer', page).checked(query.HasTrailer == false);
+        $('#chkSpecialFeature', page).checked(query.HasSpecialFeature == true);
+        $('#chkThemeSong', page).checked(query.HasThemeSong == true);
+        $('#chkThemeVideo', page).checked(query.HasThemeVideo == true);
 
         $('#selectPageSize', page).val(query.Limit);
 
         //Management
-        $('#chkMissingRating', page).checked(query.HasOfficialRating == false).checkboxradio('refresh');
-        $('#chkMissingOverview', page).checked(query.HasOverview == false).checkboxradio('refresh');
-        $('#chkYearMismatch', page).checked(query.IsYearMismatched == true).checkboxradio('refresh');
-        $('#chkIsLocked', page).checked(query.IsLocked == true).checkboxradio('refresh');
-        $('#chkMissingImdbId', page).checked(query.HasImdbId == false).checkboxradio('refresh');
-        $('#chkMissingTmdbId', page).checked(query.HasTmdbId == false).checkboxradio('refresh');
-        $('#chkMissingTvdbId', page).checked(query.HasTvdbId == false).checkboxradio('refresh');
+        $('#chkMissingRating', page).checked(query.HasOfficialRating == false);
+        $('#chkMissingOverview', page).checked(query.HasOverview == false);
+        $('#chkIsLocked', page).checked(query.IsLocked == true);
+        $('#chkMissingImdbId', page).checked(query.HasImdbId == false);
+        $('#chkMissingTmdbId', page).checked(query.HasTmdbId == false);
+        $('#chkMissingTvdbId', page).checked(query.HasTvdbId == false);
 
         //Episodes
-        $('#chkSpecialEpisode', page).checked(query.ParentIndexNumber == 0).checkboxradio('refresh');
-        $('#chkMissingEpisode', page).checked(query.IsMissing == true).checkboxradio('refresh');
-        $('#chkFutureEpisode', page).checked(query.IsUnaired == true).checkboxradio('refresh');
+        $('#chkSpecialEpisode', page).checked(query.ParentIndexNumber == 0);
+        $('#chkMissingEpisode', page).checked(query.IsMissing == true);
+        $('#chkFutureEpisode', page).checked(query.IsUnaired == true);
 
         $('#selectIncludeItemTypes').val(query.IncludeItemTypes);
 
@@ -813,14 +812,6 @@
             reloadItems(page);
         });
 
-        $('#chkYearMismatch', page).on('change', function () {
-
-            query.StartIndex = 0;
-            query.IsYearMismatched = this.checked ? true : null;
-
-            reloadItems(page);
-        });
-
         //Episodes
         $('#chkMissingEpisode', page).on('change', function () {
 
