@@ -15,10 +15,7 @@
 
     function showServerConnectionFailure() {
 
-        Dashboard.alert({
-            message: Globalize.translate("MessageUnableToConnectToServer"),
-            title: Globalize.translate("HeaderConnectionFailure")
-        });
+        alertText(Globalize.translate('MessageUnableToConnectToServer'), Globalize.translate("HeaderConnectionFailure"));
     }
 
     function getServerHtml(server) {
@@ -69,12 +66,23 @@
         page.querySelector('.serverList').innerHTML = html;
     }
 
+    function alertText(text, title) {
+        alertTextWithOptions({
+            title: title,
+            text: text
+        });
+    }
+
+    function alertTextWithOptions(options) {
+        require(['alert'], function (alert) {
+            alert(options);
+        });
+    }
+
     function showGeneralError() {
 
         Dashboard.hideLoadingMsg();
-        Dashboard.alert({
-            message: Globalize.translate('DefaultErrorMessage')
-        });
+        alertText(Globalize.translate('DefaultErrorMessage'));
     }
 
     function parentWithClass(elem, className) {
@@ -124,12 +132,10 @@
                         break;
                     case MediaBrowser.ConnectionState.ServerUpdateNeeded:
                         {
-                            Dashboard.alert(alert({
-
+                            alertTextWithOptions({
                                 text: Globalize.translate('core#ServerUpdateNeeded', 'https://emby.media'),
                                 html: Globalize.translate('core#ServerUpdateNeeded', '<a href="https://emby.media">https://emby.media</a>')
-
-                            }));
+                            });
                         }
                         break;
                     default:
@@ -284,7 +290,7 @@
 
             html += '</div>';
 
-            html += '<button is="paper-icon-button-light" class="btnInviteMenu autoSize"><i class="md-icon">' + AppInfo.moreIcon.replace('-','_') + '</i></button>';
+            html += '<button is="paper-icon-button-light" class="btnInviteMenu autoSize"><i class="md-icon">' + AppInfo.moreIcon.replace('-', '_') + '</i></button>';
 
             html += '</div>';
 
