@@ -1,21 +1,19 @@
-﻿define(['appStorage', 'jQuery', 'emby-button'], function (appStorage, $) {
+﻿define(['userSettings', 'emby-button'], function (userSettings) {
 
-    $.fn.taskButton = function (options) {
+    return function (options) {
 
-        function pollTasks(button) {
+        var button = options.button;
+
+        function pollTasks() {
 
             ApiClient.getScheduledTasks({
 
                 IsEnabled: true
 
-            }).then(function (tasks) {
-
-                updateTasks(button, tasks);
-            });
-
+            }).then(updateTasks);
         }
 
-        function updateTasks(button, tasks) {
+        function updateTasks(tasks) {
 
             var task = tasks.filter(function (t) {
 
@@ -36,12 +34,12 @@
             }
 
             if (task.State == 'Idle') {
-                $(button).removeAttr('disabled');
+                button.removeAttribute('disabled');
             } else {
-                $(button).attr('disabled', 'disabled');
+                button.setAttribute('disabled', 'disabled');
             }
 
-            $(button).attr('data-taskid', task.Id);
+            button.setAttribute('data-taskid', task.Id);
 
             var progress = (task.CurrentProgressPercentage || 0).toFixed(1);
 
@@ -72,46 +70,15 @@
             }
         }
 
-        function onScheduledTaskMessageConfirmed(instance, id) {
-            ApiClient.startScheduledTask(id).then(function () {
-
-                pollTasks(instance);
-            });
+        function onScheduledTaskMessageConfirmed(id) {
+            ApiClient.startScheduledTask(id).then(pollTasks);
         }
 
         function onButtonClick() {
 
             var button = this;
-            var id = button.getAttribute('data-taskid');
-
-            var key = 'scheduledTaskButton' + options.taskKey;
-            var expectedValue = new Date().getMonth() + '6';
-
-            if (appStorage.getItem(key) == expectedValue) {
-                onScheduledTaskMessageConfirmed(button, id);
-            } else {
-
-                var msg = Globalize.translate('ConfirmMessageScheduledTaskButton');
-                msg += '<br/>';
-                msg += '<div style="margin-top:1em;">';
-                msg += '<a class="clearLink" href="scheduledtasks.html"><button is="emby-button" type="button" style="color:#3f51b5!important;margin:0;">' + Globalize.translate('ButtonScheduledTasks') + '</button></a>';
-                msg += '</div>';
-
-                require(['confirm'], function (confirm) {
-
-                    confirm({
-
-                        title: Globalize.translate('HeaderConfirmation'),
-                        html: msg,
-                        text: Globalize.translate('ConfirmMessageScheduledTaskButton') + "\n\n" + Globalize.translate('ButtonScheduledTasks')
-
-                    }).then(function () {
-                        appStorage.setItem(key, expectedValue);
-                        onScheduledTaskMessageConfirmed(button, id);
-                    });
-
-                });
-            }
+            var taskId = button.getAttribute('data-taskid');
+            onScheduledTaskMessageConfirmed(taskId);
         }
 
         function onSocketOpen() {
@@ -123,17 +90,16 @@
 
                 var tasks = msg.Data;
 
-                updateTasks(self, tasks);
+                updateTasks(tasks);
             }
         }
 
-        var self = this;
         var pollInterval;
 
         function onPollIntervalFired() {
 
             if (!ApiClient.isWebSocketOpen()) {
-                pollTasks(self);
+                pollTasks();
             }
         }
 
@@ -162,23 +128,21 @@
 
         if (options.mode == 'off') {
 
-            this.off('click', onButtonClick);
+            button.removeEventListener('click', onButtonClick);
             Events.off(ApiClient, 'websocketmessage', onSocketMessage);
             Events.off(ApiClient, 'websocketopen', onSocketOpen);
             stopInterval();
 
-        } else if (this.length) {
+        } else {
 
-            this.on('click', onButtonClick);
+            button.addEventListener('click', onButtonClick);
 
-            pollTasks(self);
+            pollTasks();
 
             startInterval();
 
             Events.on(ApiClient, 'websocketmessage', onSocketMessage);
             Events.on(ApiClient, 'websocketopen', onSocketOpen);
         }
-
-        return this;
     };
 });
\ No newline at end of file
